# Need help with the igraph C library?

_This repository is **only** about the C library of `igraph`. Do you use `igraph` from a different language? Then please see the repositories for the [R interface](https://github.com/igraph/rigraph/), the [Python interface](https://github.com/igraph/python-igraph/) or the [Mathematica interface](https://github.com/szhorvat/IGraphM)._

Having problems with igraph?

 - First, check our [documentation](https://igraph.org/c/html/latest/) for answers.
    * Problems with installing `igraph`? Please check our [installation instructions](https://igraph.org/c/html/latest/igraph-Installation.html).
    * Problems compiling your own code? Please check our [tutorial](https://igraph.org/c/html/latest/igraph-Tutorial.html) on writing your first `igraph` program.
 - Do you have a question about `igraph`? Please post your question on our [support forum](https://igraph.discourse.group/).
 - If you **found a bug**, please go ahead and [open a new issue](https://github.com/igraph/igraph/issues).

 We use the [issue tracker](https://github.com/igraph/igraph/issues) for bug reports and feature requests, and the [support forum](https://igraph.discourse.group/) for questions.
